@@ -10,7 +10,7 @@ use Encode;
 use MIME::Base64 qw(encode_base64);
 use HTML::Entities qw(encode_entities_numeric);
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 sub init {
     my ($self) = @_;
@@ -21,7 +21,9 @@ sub init {
 sub filter {
     my ($self, $text) = @_;
 
-    my %options = ();
+    my %options     = ();
+    my @encode_args = ();
+
     if ($self->{ _CONFIG } && (ref($self->{ _CONFIG }) eq 'HASH')) {
         if ($self->{ _CONFIG }->{trim}) {
             $text =~ s/^\s+//ms;
@@ -33,9 +35,13 @@ sub filter {
             Encode::_utf8_on($text);
             $text = encode_entities_numeric($text);
         }
+        if ($self->{ _CONFIG }->{dont_broken_into_lines_each_76_char}) {
+            push @encode_args, '';
+        }
     }
+    unshift @encode_args, $text;
 
-    my $encoded = encode_base64($text);
+    my $encoded = &encode_base64(@encode_args);
 
     return $encoded
 }
@@ -52,7 +58,7 @@ Template::Plugin::Filter::Base64 - encoding b64 filter for Template Toolkit
 
 =head1 SYNOPSIS
 
-    [% USE Filter.Base64 trim => 1, use_html_entity => 'cp1251' %]
+    [% USE Filter.Base64 trim => 1, use_html_entity => 'cp1251', dont_broken_into_lines_each_76_char => 1 %]
     [% FILTER b64 %]
         Hello, world!
     [% END %]
@@ -75,6 +81,14 @@ Optional. Value means default charset (e.g. 'cp1251'). Result - convert text wit
 
 =back
 
+=over
+
+=dont_broken_into_lines_each_76_char
+
+Optional. If true, call the function MIME::Base64::encode_base64( $bytes, '' ) whith empty string for the parameter $eol. The returned encoded string is broken into lines of no more than 76 characters each and it will end with $eol unless it is empty. Pass an empty string as second argument if you do not want the encoded string to be broken into lines
+
+=back
+
 =head1 SEE ALSO
 
 MIME::Base64 - Encoding and decoding of base64 strings L<http://search.cpan.org/~gaas/MIME-Base64/Base64.pm>
